@@ -1,9 +1,9 @@
-/**************************************************
-* unit:    struct            release 0.14         *
+/*****************************************************
+* unit:    struct            release 0.17            *
 * STRUCT.H - Provides some big and little endian abstraction functions,
 *	      for manipulating with structures.	
-*   Copyright (C) 1999-2023  Jaroslav Fojtik
-**************************************************/
+*   Copyright (C) 1999-2024  Jaroslav Fojtik
+*****************************************************/
 #ifndef _STRUCT_H_
 #define _STRUCT_H_
 
@@ -22,6 +22,35 @@
 
 /* Ensure that prototypes are correctly declared even for C. */
 #ifdef __cplusplus
+
+#ifdef EXPAND_OPS
+  #ifdef LO_ENDIAN
+    inline int RdWORD_LoEnd(uint16_t *pnum,FILE*f) {return fread(pnum,1,2,f);}
+    #define RdWORD_LoEnd RdWORD_LoEnd
+    inline int RdDWORD_LoEnd(uint32_t *pnum,FILE*f) {return fread(pnum,1,4,f);}
+    #define RdDWORD_LoEnd RdDWORD_LoEnd
+    inline int RdWORD_HiEnd(uint16_t *pnum,FILE*f) {const int i=fread(pnum,1,2,f);*pnum=LD_UINT16_SWAP(pnum);return i;}
+    #define RdWORD_HiEnd RdWORD_HiEnd
+    inline int RdDWORD_HiEnd(uint32_t *pnum,FILE*f) {const int i=fread(pnum,1,4,f);*pnum=LD_UINT32_SWAP(pnum);return i;}
+    #define RdDWORD_HiEnd RdDWORD_HiEnd
+    #if defined(uint64_t_defined)
+    #endif
+  #endif
+  #ifdef HI_ENDIAN
+    inline int RdWORD_LoEnd(uint16_t *pnum,FILE*f) {const int i=fread(pnum,1,2,f);*pnum=LD_UINT16_SWAP(pnum);return i;}
+    #define RdWORD_LoEnd RdWORD_LoEnd
+    inline int RdDWORD_LoEnd(uint32_t *pnum,FILE*f) {const int i=fread(pnum,1,4,f);*pnum=LD_UINT32_SWAP(pnum);return i;}
+    #define RdDWORD_LoEnd RdDWORD_LoEnd
+    inline int RdWORD_HiEnd(uint16_t *pnum,FILE*f) {return fread(pnum,1,2,f);}
+    #define RdWORD_HiEnd RdWORD_HiEnd
+    inline int RdDWORD_HiEnd(uint32_t *pnum,FILE*f) {return fread(pnum,1,4,f);}
+    #define RdDWORD_HiEnd RdDWORD_HiEnd
+    #if defined(uint64_t_defined)
+    #endif
+  #endif
+  #undef EXPAND_OPS
+#endif
+
 extern "C" {
 #endif
 /* functions from struct.c */
@@ -32,18 +61,18 @@ extern "C" {
   #define RdWORD_LoEnd(pnum,f)		fread(pnum,1,2,f)
   #define RdDWORD_LoEnd(pnum,f)		fread(pnum,1,4,f)
   #define RdQWORD_LoEnd(pnum,f)		fread(pnum,1,8,f)
-  #define WrWORD_LoEnd(num,f)		fwrite(&num,1,2,f)
-  #define WrDWORD_LoEnd(num,f)		fwrite(&num,1,4,f)
-  #define WrQWORD_LoEnd(num,f)		fwrite(&num,1,8,f)
+  #define WrWORD_LoEnd(_num,f)		fwrite(&(_num),1,2,f)
+  #define WrDWORD_LoEnd(_num,f)		fwrite(&(_num),1,4,f)
+  #define WrQWORD_LoEnd(_num,f)		fwrite(&(_num),1,8,f)
   #define RdFLOAT_LoEnd(pnum,f)		fread(pnum,1,4,f)
-  #define WrFLOAT_LoEnd(num,f)		fwrite(&num,1,4,f)
+  #define WrFLOAT_LoEnd(_num,f)		fwrite(&(_num),1,4,f)
  #endif
  #ifdef HI_ENDIAN
-  #define RdWORD_HiEnd(num,f)		fread((num),1,2,f)
-  #define RdDWORD_HiEnd(num,f)		fread((num),1,4,f)
+  #define RdWORD_HiEnd(pnum,f)		fread((pnum),1,2,f)
+  #define RdDWORD_HiEnd(pnum,f)		fread((pnum),1,4,f)
 /* this speedup is not working on MSB - never mind
-  #define WrWORD_HiEnd(num,f)		fwrite((&num),1,2,f)
-  #define WrDWORD_HiEnd(num,f)		fwrite((&num),1,4,f)
+  #define WrWORD_HiEnd(_num,f)		fwrite((&_num),1,2,f)
+  #define WrDWORD_HiEnd(_num,f)		fwrite((&_num),1,4,f)
 */
  #endif
 #endif
@@ -74,7 +103,7 @@ extern "C" {
  int WrDWORD_HiEnd(uint32_t num, FILE *f);
 #endif
 
-#if defined(uint64_t_defined) || defined(uint64_t)
+#if defined(uint64_t_defined)
  #ifndef RdQORD_HiEnd
   int RdQWORD_HiEnd(uint64_t *num, FILE *f);
  #endif
@@ -108,8 +137,8 @@ extern "C" {
 uint16_t fil_sreadU16(const uint8_t *in);
 uint32_t fil_sreadU32(const uint8_t *in);
 
-int loadstruct(FILE *F,const char *description, ...);
-int savestruct(FILE *F,const char *description, ...);
+int loadstruct(FILE *F, const char *description, ...);
+int savestruct(FILE *F, const char *description, ...);
 
 #ifdef __cplusplus
 }
