@@ -77,7 +77,7 @@ char c;
 /** Flip R and B and invert A coupounds in place.
  * param[in]	Data	Pointer to data.
  * param[in]	Size	Amount of RGB tripplets. */
-void RGBA32_BGRiA32(char *Data, int PixelCount)
+void RGBA32_BGRiA32(unsigned char *Data, int PixelCount)
 {
 char c;
   while(PixelCount-->0)
@@ -94,7 +94,7 @@ char c;
 /** Flip R and B and invert A coupounds in place.
  * param[in]	Data	Pointer to data.
  * param[in]	Size	Amount of RGB tripplets. */
-void RGBA64_BGRiA64(char *Data, int PixelCount)
+void RGBA64_BGRiA64(unsigned char *Data, int PixelCount)
 {
 uint16_t c;
 uint16_t *Data16 = (uint16_t *)Data;
