@@ -24,7 +24,7 @@
 
 #include "common.h"	// This header ensures that __UNIX__ is properly defined.
 
-#if defined(__UNIX__) || defined(__DJGPP__) || defined(_MSC_VER) 
+#if defined(__UNIX__) || defined(__DJGPP__) || defined(_MSC_VER)
  #define SIGNALS_SUPPORTED
  #include <signal.h>
 #endif
@@ -440,7 +440,8 @@ void ShowCopyright(void)
          "\nOr you may wish to edit the WordPerfect document to remove unwanted"
          "\ncodes (such as Tab, Tab Set), then run it through wp2latex again."));
 
-  puts(_("\nThanks to:R.C.Houtepen            for initial WP2LaTeX pascal release (1990)"
+  puts(_("\nThanks to:Compile farm project    for possibility to test on CPU architectures"
+         "\n          R.C.Houtepen            for initial WP2LaTeX pascal release (1990)"
 	 "\n          Rafael Rodriguez Pappa  for several notes and bugfixes"
 	 "\n          Damil Cavar             for several bugreports"
 	 "\n          Hilmar Preusse          for translating several WP extended chars; creating"
@@ -878,17 +879,22 @@ EmptyInput:
 
 #ifdef _REENTRANT
   if(JobBase::JobCount>0)
+  {
+    if(Verbosing >= 1)
     {
-    printf(_("Note: There are some asynchronous jobs that are still running."));
-    printf("--------");
+      printf(_("Note: There are some asynchronous jobs that are still running."));
+      printf("--------");
+    }
     int SecCounter=0;
     while(JobBase::JobCount>0)
     {
-      printf("\b\b\b\b\b\b\b\b%2dj%4ds", JobBase::JobCount, SecCounter++);
+      if(Verbosing >= 1)
+          printf("\b\b\b\b\b\b\b\b%2dj%4ds", JobBase::JobCount, SecCounter++);
       FinishJobs(1000);	// Wait to finish them.
     }
-    printf(_("\nNote: All jobs finished now."));
-    }
+    if(Verbosing >= 1)
+        printf(_("\nNote: All jobs finished now."));
+  }
   EndJobs();
 #endif
 
