@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"4.7"
-#define VersionDate	"2 Jun 2024"  /* day (space) month (space) full year */
+#define VersionWP2L	"4.12"
+#define VersionDate	"6 Nov 2024"  /* day (space) month (space) full year */
 
 
 /** Constants for a flag InputPS */
@@ -33,10 +33,10 @@ typedef enum
 extern unsigned short OutCodePage, WPcharset;
 extern bool Index, Interactive, NFSS, TABs, twoside, ExactFnNumbers, CPStyles,
 	 EraseStrip, UndoRedo, Noclobber;
-extern int8_t Cyrillic, colors, EndNotes, FancyHdr, Columns, cjHebrew, InputPS, MakeIdx,
+extern int8_t arabtex, Cyrillic, colors, EndNotes, FancyHdr, Columns, cjHebrew, InputPS, MakeIdx,
 	 textcomp, Wasy, Accents, Amssymb, Arevmath, LaTeXsym, LongTable, Bbm, TIPA, fontenc,
 	 Rsfs, Ulem, pifont, PostScript, rus_yo, Rotate, Scalerel, LineNo, AmsMath,
-         SaveWPG, mxedruli;
+	 SaveWPG, mxedruli;
 extern signed char CheckOversize;
 extern int LaTeX_Version;
 extern signed char Verbosing;
@@ -49,10 +49,10 @@ typedef struct			/* Auto detection structure for file formats */
 	{
 	const char *DocumentType;
 	const char *Converter;	///< ASCII key for looking converter module.
-        const char *Extension;
+	const char *Extension;
 	uint16_t DocVersion;
 	float Probability;	///< <-1 surely not  0 don't know  1 surely yes>
-        uint32_t DocumentStart;
+	uint32_t DocumentStart;
 	} FFormatDetect;
 extern FFormatDetect FilForD;
 
@@ -66,6 +66,7 @@ extern long num_of_lines_stripfile;
 #define Heb_Font	  28
 #define Line_Num	  29
 #define Georgia_Font	  30
+#define Arabic_Font	  31
 extern int OutputStyle;
 
 
@@ -84,7 +85,6 @@ extern const TStyleOpCl *StyleOpCl;
 /* functions of wp2lfuti.c */
 int AbsolutePath(const char *TestedPath);
 FILE *OpenWrChk(const char *name, const char *type, FILE *Err);
-int  ReadAndSplitLine(FILE *fp, char *regel);
 long FileSize(FILE *f);
 #define Rd_word(f,w) RdWORD_LoEnd(w,f);
 #define Rd_dword(f,d) RdDWORD_LoEnd(d,f);
@@ -103,8 +103,6 @@ uint32_t w_fgetc(FILE *F);
 uint32_t W_fgetc(FILE *F);
 
 
-//struct RGBQuad;
-
 void LoadConfigFile(const char *filename);
 int CheckFileFormat(FILE *wpd,FFormatDetect & FilForD);
 
@@ -260,6 +258,22 @@ public:
 #endif
 };
 
+/* global functions of pass1.cc */
+void Finalise_Conversion(TconvertedPass1 *cq);
+void Make_tableentry_envir_extra_end(TconvertedPass1 *cq);
+void Make_tableentry_attr(TconvertedPass1 *cq);
+void Make_tableentry_tabset(TconvertedPass1 *cq);
+void Initialise_Conversion(TconvertedPass1 *cq);
+void AttrOff(TconvertedPass1 *cq, char attr_num);
+void Attr_ON(TconvertedPass1 *cq,unsigned char b=0xFF);
+void Attr_OFF(TconvertedPass1 *cq,unsigned char b=0xFF);
+void CancelHyph(TconvertedPass1 *cq);
+void CellTable(TconvertedPass1 *cq);
+void Center(TconvertedPass1 *cq);
+void CenterPage(TconvertedPass1 *cq);
+void CharacterStr(TconvertedPass1 *cq,const char *LatexCode);
+
+
 void ReportNoMemory(TconvertedPass1 *cq=NULL);
 
 
@@ -281,7 +295,8 @@ typedef enum
   FONT_NORMAL = 1,
   FONT_CYRILLIC = 2,
   FONT_HEBREW = 3,
-  FONT_GEORGIA = 4
+  FONT_GEORGIA = 4,
+  FONT_ARABIC = 5
 } FontTypes;
 
 
@@ -301,20 +316,6 @@ typedef enum {aExtraLarge=0, aVeryLarge1=1, aLarge=2, aSmall=3, aFine=4,
 	      aRedline=10, aDblUnderline=11, aBold=12, aStrikeOut=13,
 	      aUnderline=14, aSmallCaps=15 } TxtAttrs;
 
-/* global functions of pass1.cc */
-void Finalise_Conversion(TconvertedPass1 *cq);
-void Make_tableentry_envir_extra_end(TconvertedPass1 *cq);
-void Make_tableentry_attr(TconvertedPass1 *cq);
-void Make_tableentry_tabset(TconvertedPass1 *cq);
-void Initialise_Conversion(TconvertedPass1 *cq);
-void AttrOff(TconvertedPass1 *cq, char attr_num);
-void Attr_ON(TconvertedPass1 *cq,unsigned char b=0xFF);
-void Attr_OFF(TconvertedPass1 *cq,unsigned char b=0xFF);
-void CancelHyph(TconvertedPass1 *cq);
-void CellTable(TconvertedPass1 *cq);
-void Center(TconvertedPass1 *cq);
-void CenterPage(TconvertedPass1 *cq);
-void CharacterStr(TconvertedPass1 *cq,const char *LatexCode);
 #ifdef __Rasters_h
 void Color(TconvertedPass1 *cq, signed char WP, RGBQuad *RGB=NULL);
 #endif
@@ -547,7 +548,7 @@ typedef struct
   bool		UseCpStyles;
 } TOutCodePage;
 
-extern const TOutCodePage OutCodepages[11];
+extern const TOutCodePage OutCodepages[12];
 
 
 #ifndef FINAL
